*+--------------------------------------------------------------------
*+    Source Module => /home/paul/click/profile.prg
*+    Click! is a Clipper/Xbase++ source code reformatter.
*+    Note:Phil is no longer actively developing Click!.
*+    Copyright(C) 1996-1999 by Phil Barnett.
*+    This program is free software; you can redistribute it and/or modify it
*+    under the terms of the GNU General Public License as published by the
*+    Free Software Foundation; either version 2 of the License, or (at your
*+    option) any later version.
*+    This program is distributed in the hope that it will be useful, but
*+    WITHOUT ANY WARRANTY; without even the implied warranty of
*+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*+    General Public License for more details.
*+    You should have received a copy of the GNU General Public License along
*+    with this program; if not, contact the Free Software Foundation, Inc.,
*+    51 Franklin St, Fifth Floor Boston, MA 02110, USA, or www.fsf.org.
*+    You can contact me at:
*+    Phil Barnett
*+    Box 944
*+    Plymouth, Florida  32768
*+    or
*+    philb@iag.net
*+    Ported to Linux and xHarbour compiler, minor feature additions.
*+    Changed version to 3.00xHarbour  Changes
*+    GPL version 3 Copyright (C) 2006-9 by Paul States
*+    Contact:broadcastmail AT NOSPAM 123mail.org.
*+    Functions: Function ProfileString()
*+               Function ProfileNum()
*+               Function ProfileDate()
*+               STATIC Function init_profile()
*+    Reformatted by Click! 3.00Harbour on Apr-13-2009 at  2:30 pm
*+--------------------------------------------------------------------

#include "common.ch"

STATIC INI_DATA := {}
STATIC INI_NAME := ''

*+--------------------------------------------------------------------
*+    Function ProfileString()
*+    Called from ( click.prg    )  39 - procedure click()
*+                                   2 - STATIC procedure thealigner()
*+                ( declbust.prg )   4 - procedure declbust()
*+                ( functrak.prg )   2 - procedure init_func_text()
*+                                  11 - procedure func_text()
*+                ( libread.prg  )   1 - procedure libread()
*+                ( obufwrit.prg )   1 - function bo_init()
*+                ( profile.prg  )   1 - function profilenum()
*+                                   1 - function profiledate()
*+       Calls    ( profile.prg  )   1 - STATIC function init_profile()
*+--------------------------------------------------------------------
FUNCTION ProfileString( cFile, cSection, cKey, cDefault )

//
//  This function reads a string from the specified .INI file.
//
//  Parameters: cFile    - The .INI file name to be used
//              cSection - The section from which to read
//              cKey     - The key value for which to search
//              cDefault - The default value if not found (optional)
//
//     Returns: cString - The string read from the file.
//

LOCAL nSPointer := 0
LOCAL nKPointer := 0
LOCAL cString

DEFAULT cDefault TO ''
cString := cDefault

BEGIN SEQUENCE

  IF INI_NAME <> cFile
    IF !init_profile( cFile )
      BREAK
    ENDIF
  ENDIF

  cSection := UPPER( ALLTRIM( cSection ) )
  cKey     := UPPER( ALLTRIM( cKey ) )

  IF LEFT( cSection, 1 ) <> '['
    cSection := '[' + cSection
  ENDIF

  IF RIGHT( cSection, 1 ) <> ']'
    cSection += ']'
  ENDIF

  nSPointer := ASCAN( INI_DATA, { | x | x[ 1 ] == cSection } )

  IF !EMPTY( nSPointer )
    nKPointer := ASCAN( INI_DATA[ nSPointer, 2 ], { | x | x[ 1 ] == cKey } )
    IF !EMPTY( nKPointer )
      cString := INI_DATA[ nSPointer, 2, nKPointer, 2 ]
    ENDIF
  ENDIF

END SEQUENCE
RETURN cString

*+--------------------------------------------------------------------
*+    Function ProfileNum()
*+    Called from ( click.prg    )  12 - procedure click()
*+                ( libread.prg  )   1 - procedure libread()
*+       Calls    ( profile.prg  )   1 - STATIC function init_profile()
*+                ( profile.prg  )   1 - function profilestring()
*+--------------------------------------------------------------------
FUNCTION ProfileNum( cFile, cSection, cKey, nDefault )

//
//  This function reads a number from the specified .INI file.
//
//  Parameters: cFile    - The .INI/.ini file name to be used
//              cSection - The section from which to read
//              cKey     - The key value for which to search
//              nDefault - The default value if not found (optional)
//
//     Returns: nValue - The numeric value read from the file.
//

LOCAL retval

DEFAULT nDefault TO 0
retval := nDefault

BEGIN SEQUENCE

  IF INI_NAME <> cFile
    IF !init_profile( cFile )
      BREAK
    ENDIF
  ENDIF

  retval := ProfileString( cFile, cSection, cKey, '' )

  IF EMPTY( retval )
    retval := nDefault
  ELSE
    retval := VAL( retval )
  ENDIF

END SEQUENCE

RETURN retval

*+--------------------------------------------------------------------
*+    Function ProfileDate()
*+       Calls    ( profile.prg  )   1 - STATIC function init_profile()
*+                ( profile.prg  )   1 - function profilestring()
*+--------------------------------------------------------------------
FUNCTION ProfileDate( cFile, cSection, cKey, dDefault )

//
//  This function reads a date from the specified .INI file.
//
//  Parameters: cFile    - The .INI file name to be used
//              cSection - The section from which to read
//              cKey     - The key value for which to search
//              dDefault - The default date if not found (optional)
//
//     Returns: dDate - The date value read from the file.
//
LOCAL retval

DEFAULT dDefault TO CTOD( '' )
retval := dDefault

BEGIN SEQUENCE

  IF INI_NAME <> cFile
    IF !init_profile( cFile )
      BREAK
    ENDIF
  ENDIF

  retval := ProfileString( cFile, cSection, cKey, '' )

  IF EMPTY( retval )
    retval := dDefault
  ELSE
    retval := CTOD( retval )
  ENDIF

END SEQUENCE

RETURN retval

/*
function SetProfile( cFile, cSection, cKey, xValue )
//
//  This function writes a value to the .INI file specified.
//
//  Parameters: cFile    - The .INI file name to be used
//              cSection - The section for which to search
//              cKey     - The key value for which to search
//              xValue   - The new value to be written
//
//     Returns: .T. if successful, .F. otherwise.
//

Remember: When implementing this section that init_profile() throws away
anything that is empty line, comment (//) and anything that is not
either a section header or a line with no = sign.

This means that this section absolutely cannot rely on init_profile()
and must have it's own file reader/writer

return lRetCode
*/

*+--------------------------------------------------------------------
*+    STATIC Function init_profile()
*+    Called from ( profile.prg  )   1 - function profilestring()
*+                                   1 - function profilenum()
*+                                   1 - function profiledate()
*+       Calls    ( obufread.prg )   1 - function bclose()
*+                ( obufread.prg )   1 - function beof()
*+                ( obufread.prg )   1 - function binit()
*+                ( obufread.prg )   1 - function bopen()
*+                ( obufread.prg )   1 - function breadline()
*+--------------------------------------------------------------------
STATIC FUNCTION init_profile( cFile )

LOCAL oBufObj       := bInit( cFile )
LOCAL retval        := bopen( oBufObj )
LOCAL cThisLine
LOCAL lFoundSection := .F.
LOCAL nLastElement  := 0
LOCAL eqat

INI_DATA := {}
INI_NAME := ''

IF retval
  INI_NAME := cFile
  DO WHILE !bEof( oBufObj )

    cThisLine := ALLTRIM( bReadLine( oBufObj ) )

    IF EMPTY( cThisLine ) .OR. LEFT( cThisLine, 2 ) == '//'
      LOOP
    ENDIF

    IF !lFoundSection
      IF LEFT( cThisLine, 1 ) == '[' .AND. RIGHT( cThisLine, 1 ) == ']'
        lFoundSection := .T.
      ELSE
        LOOP
      ENDIF
    ENDIF

    IF LEFT( cThisLine, 1 ) == '[' .AND. RIGHT( cThisLine, 1 ) == ']'
      AADD( INI_DATA, { UPPER( cThisLine ), {} } )
      nLastElement ++
    ELSE
      eqat := AT( '=', cThisLine )
      IF eqat > 0
        AADD( INI_DATA[ nLastElement, 2 ], ;
          { UPPER( ALLTRIM( LEFT( cThisLine, eqat - 1 ) ) ), ;
          SUBSTR( cThisLine, eqat + 1 ) } )
      ENDIF
    ENDIF
  ENDDO
  bClose( oBufObj )
ENDIF

RETURN retval

*+ EOF: profile.prg
